from setuptools import setup, find_packages

setup(
    name='keyboardhumanizer',
    version='0.1.3',
    description='Human-like keyboard automation',
    author='Your Name',
    packages=find_packages(),
    include_package_data=True,
    python_requires='>=3.7',
) 